@@ -1,6 +1,8 @@
 import os
+from datetime import timedelta
 
 import torch.distributed
+from torch.distributed.constants import default_pg_timeout
 
 __all__ = ['init', 'size', 'rank', 'local_size', 'local_rank', 'is_master']
 
@@ -8,8 +10,9 @@ _world_size, _world_rank = 1, 0
 _local_size, _local_rank = 1, 0
 
 
-def init() -> None:
-    from mpi4py import MPI  # type: ignore
+def init(backend: int = 'nccl',
+         timeout: timedelta = default_pg_timeout) -> None:
+    from mpi4py import MPI
     world_comm = MPI.COMM_WORLD
     local_comm = MPI.COMM_WORLD.Split_type(MPI.COMM_TYPE_SHARED)
 
@@ -18,8 +21,9 @@ def init() -> None:
     _local_size, _local_rank = local_comm.Get_size(), local_comm.Get_rank()
 
     master_host = 'tcp://' + os.environ['MASTER_HOST']
-    torch.distributed.init_process_group(backend='nccl',
+    torch.distributed.init_process_group(backend=backend,
                                          init_method=master_host,
+                                         timeout=timeout,
                                          world_size=_world_size,
                                          rank=_world_rank)
 
